from charmhelpers.core.hookenv import (
    action_get,
    action_fail,
    action_set,
    config,
    status_set,
)

from charms.reactive import (
    remove_state as remove_flag,
    set_state as set_flag,
    when, when_not
)

import charms.sshproxy

@when_not('magmagw.installed')
def install_magmagw():
    # Do your setup here.
    #
    # If your charm has other dependencies before it can install,
    # add those as @when() clauses above., or as additional @when()
    # decorated handlers below
    #
    # See the following for information about reactive charms:
    #
    #  * https://jujucharms.com/docs/devel/developer-getting-started
    #  * https://github.com/juju-solutions/layer-basic#overview
    #
    set_flag('magmagw.installed')

@when('actions.reset-id')
def reset_id():
    err = ''
    try:
        cmd = "sudo snowflake --force-new-key"
        result, err = charms.sshproxy._run(cmd)
    except:
        action_fail('command failed:' + err)
    else:
        action_set({'output': result})
    finally:
        remove_flag('actions.reset-id')

@when('actions.add-net')
def add_net():
    err = ''    
    orch_ip = action_get('orch_ip')    
    orch_net = action_get('orch_net')
    try:
        cmd = "/home/magma/addnet.py --orch_ip " + orch_ip + " --orch_net " + orch_net
        result, err = charms.sshproxy._run(cmd)
    except:
        action_fail('command failed:' + err)
    else:
        action_set({'output': result})
    finally:
        remove_flag('actions.add-net')

@when('actions.add-gw')
def add_gw():
    err = ''
    agw_id = action_get('agw_id')
    agw_name = action_get('agw_name')    
    orch_ip = action_get('orch_ip')    
    orch_net = action_get('orch_net')
    try:
        cmd = "/home/magma/addgw.py --agw_id " + agw_id + " --agw_name " + agw_name + " --orch_ip " + orch_ip + " --orch_net " + orch_net
        result, err = charms.sshproxy._run(cmd)
    except:
        action_fail('command failed:' + err)
    else:
        action_set({'output': result})
    finally:
        remove_flag('actions.add-gw')

@when('actions.add-hosts')
def add_hosts():
    err = ''
    orch_ip = action_get('orch_ip')    
    try:
        orch_hosts="ORCH_IP controller.magma.test\nORCH_IP bootstrapper-controller.magma.test\nORCH_IP state-controller.magma.test\nORCH_IP dispatcher-controller.magma.test\nORCH_IP logger-controller.magma.test\nORCH_IP streamer-controller.magma.test\n"
        orch_hosts=orch_hosts.replace("ORCH_IP",orch_ip)
        cmd = "echo -e " + orch_hosts + " | sudo tee -a /etc/hosts"
        result, err = charms.sshproxy._run(cmd)        
    except:
        action_fail('command failed:' + err)
    else:
        action_set({'output': result})
    finally:
        remove_flag('actions.add-hosts')        

@when('actions.restart-magma')
def restart_magma():
    err = ''
    try:
        cmd = "sudo service magma@* restart"
        result, err = charms.sshproxy._run(cmd)
    except:
        action_fail('command failed:' + err)
    else:
        action_set({'output': result})
    finally:
        remove_flag('actions.restart-magma')        

@when('actions.del-gw')
def del_gw():
    err = ''
    agw_id = action_get('agw_id')    
    orch_ip = action_get('orch_ip')    
    orch_net = action_get('orch_net')
    try:
        cmd = "/home/magma/delgw.py --agw_id " + agw_id + " --orch_ip " + orch_ip + " --orch_net " + orch_net
        result, err = charms.sshproxy._run(cmd)
    except:
        action_fail('command failed:' + err)
    else:
        action_set({'output': result})
    finally:
        remove_flag('actions.del-gw')        